@@ -514,45 +514,14 @@ generate_random_params <- function(param, verbose = FALSE) {
       stop("`param.random.set` must be a data.frame")
     }
 
-    # Check the format of the names
-    set.elements <- names(param.random.set)
-    correct_format <- grepl("^[a-zA-Z0-9.]*(_[0-9]+)?$", set.elements)
-    if (!all(correct_format)) {
-      stop("The following column names in `param.random.set` are malformed: \n",
-        paste0(set.elements[!correct_format], collapse = ", "), "\n\n",
-        "you can check the names with ",
-        '`grepl("^[a-zA-Z0-9.]*(_[0-9]+)?$", your.names)` \n',
-        "Example: 'unique.param', 'param.set_1', 'param.set_2'"
-      )
-    }
-
-    # Construct a `data.frame` matching the names with the parameters
-    set.elements <- names(param.random.set)
-    set.elements.split <- data.frame(do.call(
-      rbind,
-      strsplit(set.elements, "_")
-    ))
-
-    nums <- grepl("^[0-9]+$", set.elements.split[, 2])
-    set.elements.split[, 2] <- as.numeric(
-      ifelse(nums, set.elements.split[, 2], "1")
-    )
-
-    set.elements <- cbind(set.elements, set.elements.split)
-    colnames(set.elements) <- c("name", "param", "position")
-
     # Pick one row of the `data.frame`
     sampled.row <- sample.int(nrow(param.random.set), 1)
-    param.random.set <- param.random.set[sampled.row, ]
 
-    # Set the new values in `rng_values`
-    for (i in seq_len(nrow(set.elements))) {
-      value <- param.random.set[1, set.elements[i, "name"][[1]]]
-      parameter <- set.elements[i, "param"][[1]]
-      position <- set.elements[i, "position"][[1]]
+    # Convert to `param` format
+    sampled.set <- unflatten_params(param.random.set[sampled.row, ])
 
-      rng_values[[parameter]][position] <- value
-    }
+    # Update `rng_values`
+    rng_values <- update_list(rng_values, sampled.set)
   }
 
   if (!all(vapply(random.params, is.function, TRUE))) {
@@ -568,9 +537,7 @@ generate_random_params <- function(param, verbose = FALSE) {
   }
 
   rng_values[rng_names] <- lapply(random.params, do.call, args = list())
-  for (nm in rng_names) {
-    param[nm] <- rng_values[nm]
-  }
+  param <- update_list(param, rng_values)
 
   param[["random.params.values"]] <- rng_values
 
@@ -686,196 +653,160 @@ init.net <- function(i.num, r.num, i.num.g2, r.num.g2,
 #' @title Control Settings for Stochastic Network Models
 #'
 #' @description Sets the controls for stochastic network models simulated with
-#'              \code{\link{netsim}}.
+#'              [`netsim`].
 #'
-#' @param type Disease type to be modeled, with the choice of \code{"SI"} for
-#'        Susceptible-Infected diseases, \code{"SIR"} for
-#'        Susceptible-Infected-Recovered diseases, and \code{"SIS"} for
+#' @param type Disease type to be modeled, with the choice of `"SI"` for Susceptible-Infected
+#'        diseases, `"SIR"` for Susceptible-Infected-Recovered diseases, and `"SIS"` for
 #'        Susceptible-Infected-Susceptible diseases.
-#' @param nsteps Number of time steps to simulate the model over. This must be a
-#'        positive integer that is equal to the final step of a simulation. If
-#'        simulation is restarted with \code{start} argument, this number must
-#'        be at least one greater than that argument's value.
+#' @param nsteps Number of time steps to simulate the model over. This must be a positive integer
+#'        that is equal to the final step of a simulation. If a simulation is restarted with `start`
+#'        argument, this number must be at least one greater than that argument's value.
 #' @param nsims The total number of disease simulations.
-#' @param ncores Number of processor cores to run multiple simulations
-#'        on, using the \code{foreach} and \code{doParallel} implementations.
-#' @param start For models with network resimulation, time point to start up
-#'        simulation. For restarted simulations, this must be one greater than
-#'        the final time step in the prior simulation and must be less than the
-#'        value in \code{nsteps}.
-#' @param resimulate.network If \code{TRUE}, resimulate the network at each time
-#'        step. This is required when the epidemic or demographic processes
-#'        impact the network structure (e.g., vital dynamics).
-#' @param tergmLite Logical indicating usage of either \code{tergm}
-#'        (\code{tergmLite = FALSE}), or \code{tergmLite}
-#'        (\code{tergmLite = TRUE}). Default of \code{FALSE}.
-#' @param cumulative.edgelist If \code{TRUE}, calculates a cumulative edgelist
-#'        within the network simulation module. This is used when tergmLite is
-#'        used and the entire networkDynamic object is not used.
-#' @param truncate.el.cuml Number of time steps of the cumulative edgelist to
-#'        retain. See help file for \code{\link{update_cumulative_edgelist}} for
-#'        options.
-#' @param attr.rules A list containing the  rules for setting the attributes of
-#'        incoming nodes, with one list element per attribute to be set (see
-#'        details below).
-#' @param epi.by A character vector of length 1 containing a nodal attribute for
-#'        which subgroup epidemic prevalences should be calculated. This nodal
-#'        attribute must be contained in the network model formation formula,
-#'        otherwise it is ignored.
-#' @param initialize.FUN Module to initialize the model at time 1, with the
-#'        default function of \code{\link{initialize.net}}.
-#' @param departures.FUN Module to simulate departure or exit, with the default
-#'        function of \code{\link{departures.net}}.
-#' @param arrivals.FUN Module to simulate arrivals or entries, with the default
-#'        function of \code{\link{arrivals.net}}.
-#' @param recovery.FUN Module to simulate disease recovery, with the default
-#'        function of \code{\link{recovery.net}}.
-#' @param resim_nets.FUN Module to resimulate the network at each time step,
-#'        with the default function of \code{\link{resim_nets}}.
-#' @param infection.FUN Module to simulate disease infection, with the default
-#'        function of \code{\link{infection.net}}.
-#' @param nwupdate.FUN Module to handle updating of network structure and nodal
-#'        attributes due to exogenous epidemic model processes, with the default
-#'        function of \code{\link{nwupdate.net}}.
-#' @param prevalence.FUN Module to calculate disease prevalence at each time
-#'        step, with the default function of \code{\link{prevalence.net}}.
-#' @param verbose.FUN Module to print simulation progress to screen, with the
-#'        default function of \code{\link{verbose.net}}.
-#' @param module.order A character vector of module names that lists modules in
-#'        the order in which they should be evaluated within each time step. If
-#'        \code{NULL}, the modules will be evaluated as follows: first any
-#'        new modules supplied through \code{...} in the order in which they are
-#'        listed, then the built-in modules in the order in which they are
-#'        listed as arguments above. \code{initialize.FUN} will
-#'        always be run first and \code{verbose.FUN} will always be run last.
-#' @param save.nwstats If \code{TRUE}, save network statistics in a data frame.
-#'        The statistics to be saved are specified in the \code{nwstats.formula}
-#'        argument.
-#' @param nwstats.formula A right-hand sided ERGM formula that includes network
-#'        statistics of interest, with the default to the formation formula
-#'        terms.
-#' @param save.network If \code{TRUE}, networkDynamic/network object is
-#'        saved at simulation end. Implicit reset to \code{FALSE} if
-#'        \code{tergmLite = TRUE} (because network history is not saved with
-#'        tergmLite).
-#' @param save.transmat If \code{TRUE}, complete transmission matrix is saved at
-#'        simulation end. Default of \code{TRUE}.
-#' @param save.other A character vector of elements on the \code{dat} main data
-#'        list to save out after each simulation. One example for base models is
-#'        the attribute list, \code{"attr"}, at the final time step.
-#' @param verbose If \code{TRUE}, print model progress to the console.
-#' @param verbose.int Time step interval for printing progress to console, where
-#'        0 prints completion status of entire simulation and positive integer
-#'        \code{x} prints progress after every \code{x} time steps. The default
-#'        is to print progress after each time step.
-#' @param skip.check If \code{TRUE}, skips the default error checking for the
-#'        structure and consistency of the parameter values, initial conditions,
-#'        and control settings before running base epidemic models. Setting
-#'        this to \code{FALSE} is recommended when running models with new
+#' @param ncores Number of processor cores to run multiple simulations on, using the `foreach` and
+#'        `doParallel` implementations.
+#' @param start For models with network resimulation, time point to start up the simulation. For
+#'        restarted simulations, this must be one greater than the final time step in the prior
+#'        simulation and must be less than the value in `nsteps`.
+#' @param resimulate.network If `TRUE`, resimulate the network at each time step. This is required
+#'        when the epidemic or demographic processes impact the network structure (e.g., vital
+#'        dynamics).
+#' @param tergmLite Logical indicating usage of either `tergm` (`tergmLite = FALSE`), or `tergmLite`
+#'        (`tergmLite = TRUE`). Default of `FALSE`.
+#' @param cumulative.edgelist If `TRUE`, calculates a cumulative edgelist within the network
+#'        simulation module. This is used when tergmLite is used and the entire networkDynamic
+#'        object is not used.
+#' @param truncate.el.cuml Number of time steps of the cumulative edgelist to retain. See help for
+#'        [`update_cumulative_edgelist`] for options.
+#' @param attr.rules A list containing the  rules for setting the attributes of incoming nodes, with
+#'        one list element per attribute to be set (see details below).
+#' @param epi.by A character vector of length 1 containing a nodal attribute for which subgroup
+#'        stratified prevalence summary statistics are calculated. This nodal attribute must be
+#'        contained in the network model formation formula, otherwise it is ignored.
+#' @param initialize.FUN Module to initialize the model at time 1, with the default function of
+#'        [`initialize.net`].
+#' @param departures.FUN Module to simulate departure or exit, with the default function of
+#'        [`departures.net`].
+#' @param arrivals.FUN Module to simulate arrivals or entries, with the default function of
+#'        [`arrivals.net`].
+#' @param recovery.FUN Module to simulate disease recovery, with the default function of
+#'        [`recovery.net`].
+#' @param resim_nets.FUN Module to resimulate the network at each time step, with the default
+#'        function of [`resim_nets`].
+#' @param infection.FUN Module to simulate disease infection, with the default function of
+#'        [`infection.net`].
+#' @param nwupdate.FUN Module to handle updating of network structure and nodal attributes due to
+#'        exogenous epidemic model processes, with the default function of [`nwupdate.net`].
+#' @param prevalence.FUN Module to calculate disease prevalence at each time step, with the default
+#'        function of [`prevalence.net`].
+#' @param verbose.FUN Module to print simulation progress to screen, with the default function of
+#'        [`verbose.net`].
+#' @param module.order A character vector of module names that lists modules in the order in which
+#'        they should be evaluated within each time step. If `NULL`, the modules will be evaluated
+#'        as follows: first any new modules supplied through `...` in the order in which they are
+#'        listed, then the built-in modules in the order in which they are listed as arguments
+#'        above. `initialize.FUN` will always be run first and `verbose.FUN` will always be run last.
+#' @param save.nwstats If `TRUE`, save network statistics in a data frame. The statistics to be
+#'        saved are specified in the `nwstats.formula` argument.
+#' @param nwstats.formula A right-hand sided ERGM formula that includes network statistics of
+#'        interest, with the default to the formation formula terms.
+#' @param save.network If `TRUE`, networkDynamic or network object is saved at simulation end.
+#'        This is implicitly reset to `FALSE` if `tergmLite = TRUE` (because network history is not
+#'        saved with tergmLite).
+#' @param save.transmat If `TRUE`, complete transmission matrix is saved at simulation end.
+#' @param save.other A character vector of elements on the `dat` main data list to save out after
+#'        each simulation. One example for base models is the attribute list, `"attr"`, at the final
+#'        time step.
+#' @param verbose If `TRUE`, print model progress to the console.
+#' @param verbose.int Time step interval for printing progress to console, where `0` prints
+#'        completion status of entire simulation and positive integer `x` prints progress after
+#'        every `x` time steps. The default is to print progress after each time step.
+#' @param skip.check If `TRUE`, skips the default error checking for the structure and consistency
+#'        of the parameter values, initial conditions, and control settings before running base
+#'        epidemic models. Setting this to `FALSE` is recommended when running models with new
 #'        modules specified.
-#' @param raw.output If \code{TRUE}, \code{netsim} will output a list of netsim
-#'        data (one per simulation) instead of a formatted \code{netsim} object.
-#' @param tergmLite.track.duration If \code{TRUE}, track duration information
-#'        for models in \code{tergmLite} simulations.
-#' @param set.control.ergm Control arguments passed to \code{ergm}'s
-#'        \code{simulate_formula.network}.  In \code{netsim}, this is only used
-#'        when initializing the network with \code{edapprox = TRUE}; all other
-#'        simulations in \code{netsim} use \code{tergm}.
-#' @param set.control.tergm Control arguments passed to \code{tergm}'s
-#'        \code{simulate_formula.network}. See the help file for
-#'        \code{\link{netdx}} for details and examples on specifying this
-#'        parameter.
-#' @param set.control.stergm Deprecated control argument of class
-#'        \code{control.simulate.network}; use \code{set.control.tergm}
-#'        instead.
-#' @param save.diss.stats If \code{TRUE}, \code{netsim} will compute and save
-#'        duration/dissolution statistics for plotting and printing, provided
-#'        \code{save.network} is \code{TRUE}, \code{tergmLite} is \code{FALSE},
-#'        and the dissolution model is homogeneous.
+#' @param raw.output If `TRUE`, `netsim` will output a list of raw data (one per simulation) instead
+#'        of a cleaned and formatted `netsim` object.
+#' @param tergmLite.track.duration If `TRUE`, track duration information for models in `tergmLite`
+#'        simulations.
+#' @param set.control.ergm Control arguments passed to `ergm::simulate_formula.network`. In `netsim`,
+#'        this is only used when initializing the network with `edapprox = TRUE`. All other
+#'        simulations in `netsim` use `tergm`.
+#' @param set.control.tergm Control arguments passed to `tergm::simulate_formula.network`. See the
+#'        help file for [`netdx`] for details and examples on specifying this parameter.
+#' @param set.control.stergm Deprecated control argument of class `control.simulate.network`. Use
+#'        `set.control.tergm` instead.
+#' @param save.diss.stats If `TRUE`, `netsim` will compute and save duration and dissolution
+#'        statistics for plotting and printing, provided `save.network` is `TRUE`, `tergmLite` is
+#'        `FALSE`, and the dissolution model is homogeneous.
 #' @param ... Additional control settings passed to model.
 #'
 #' @details
-#' \code{control.net} sets the required control settings for any network model
-#' solved with the \code{\link{netsim}} function. Controls are required for both
-#' base model types and when passing original process modules. For an overview
-#' of control settings for base models, consult the
-#' \href{http://www.epimodel.org/tut.html}{Basic Network Models} tutorials.
-#' For all base models, the \code{type} argument is a necessary parameter
-#' and it has no default.
+#' `control.net` sets the required control settings for any network model solved with the [`netsim`]
+#' function. Controls are required for both base model types and when passing original process
+#' modules. For an overview of control settings for base models, consult the
+#' [Basic Network Models](http://www.epimodel.org/tut.html) tutorials. For all base models, the
+#' `type` argument is a necessary parameter and it has no default.
 #'
-#' @section The \code{attr.rules} Argument:
-#' The \code{attr.rules} parameter is used to specify the rules for how nodal
-#' attribute values for incoming nodes should be set. These rules are only
-#' necessary for models in which there are incoming nodes (i.e., arrivals).
-#' There are three rules available for each attribute value:
-#' \itemize{
-#'  \item \strong{"current":} new nodes will be assigned this attribute in
-#'        proportion to the distribution of that attribute among existing nodes
-#'        at that current time step.
-#'  \item \strong{"t1":} new nodes will be assigned this attribute in proportion
-#'        to the distribution of that attribute among nodes at time 1 (that is,
-#'        the proportions set in the original network for \code{\link{netest}}).
-#'  \item \strong{<Value>:} all new nodes will be assigned this specific value,
-#'        with no variation.
-#' }
-#' For example, the rules list
-#' \code{attr.rules = list(race = "t1", sex = "current", status = "s")}
-#' specifies how the race, sex, and status attributes should be set for incoming
-#' nodes. By default, the rule is "current" for all attributes except status,
-#' in which case it is "s" (that is, all incoming nodes are susceptible).
+#' @section The attr.rules Argument:
+#' The \code{attr.rules} parameter is used to specify the rules for how nodal attribute values for
+#' incoming nodes should be set. These rules are only necessary for models in which there are
+#' incoming nodes (i.e., arrivals). There are three rules available for each attribute value:
+#'  * **`current`**: new nodes will be assigned this attribute in proportion to the distribution of
+#'    that attribute among existing nodes at that current time step.
+#'  * **`t1`**: new nodes will be assigned this attribute in proportion to the distribution of that
+#'    attribute among nodes at time 1 (that is, the proportions set in the original network for
+#'    [`netest`]).
+#'  * **`Value`**: all new nodes will be assigned this specific value, with no variation.
+#' For example, the rules list `attr.rules = list(race = "t1", sex = "current", status = "s")`
+#' specifies how the race, sex, and status attributes should be set for incoming nodes. By default,
+#' the rule is `"current"` for all attributes except status, in which case it is `"s"` (that is, all
+#' incoming nodes are susceptible).
 #'
 #' @section Checkpointing Simulations:
-#' \code{netsim} has a built-in checkpoint system to prevent losing computation
-#' work if the function is interrupted (SIGINT, power loss, time limit exceeded
-#' on a computation cluster). When enabled, each simulation will be saved every
-#' \code{.checkpoint.steps} time steps. Then, if a checkpoint enabled simulation
-#' is launched again with \code{netsim}, it will restart at the last checkpoint
-#' available in the saved data.
+#' `netsim` has a built-in checkpoint system to prevent losing computation work if the function is
+#' interrupted (SIGINT, power loss, time limit exceeded on a computation cluster). When enabled,
+#' each simulation will be saved every `.checkpoint.steps` time steps. Then, if a checkpoint enabled
+#' simulation is launched again with `netsim`, it will restart at the last checkpoint available in
+#' the saved data.
 #'
-#' To enable the checkpoint capabilities of \code{netsim}, two control arguments
-#' have to be set: \code{.checkpoint.steps}, which is a positive number of time
-#' steps to be run between each file save; and \code{.checkpoint.dir}, which is
-#' the path to a directory to save the checkpointed data. If
-#' \code{.checkpoint.dir} directory does not exist, \code{netsim} will attempt
-#' to create it on the first checkpoint save. With these two controls defined,
-#' one can simply re-run \code{netsim} with the same arguments to restart a set
-#' of simulations that were interrupted.
+#' To enable the checkpoint capabilities of `netsim`, two control arguments have to be set:
+#' `.checkpoint.steps`, which is a positive number of time steps to be run between each file save;
+#' and `.checkpoint.dir`, which is the path to a directory to save the checkpointed data. If
+#' `.checkpoint.dir` directory does not exist, `netsim` will attempt to create it on the first
+#' checkpoint save. With these two controls defined, one can simply re-run `netsim` with the same
+#' arguments to restart a set of simulations that were interrupted.
 #'
-#' Simulations are checkpointed individually: for example, if 3 simulations are
-#' run on a single core, the first 2 are finished, then the interruption occurs
-#' during the third, \code{netsim} will only restart the third one from the last
-#' checkpoint.
+#' Simulations are checkpointed individually: for example, if 3 simulations are run on a single core,
+#' the first 2 are finished, then the interruption occurs during the third, \code{netsim} will only
+#' restart the third one from the last checkpoint.
 #'
-#' A \code{.checkpoint.compress} argument can be set to overwrite the
-#' \code{compress} argument in \code{saveRDS} used to save the checkpointed
-#' data. The current default for \code{saveRDS} is \code{gunzip (gz)}, which
-#' provides fast compression that usually works well on \code{netsim} objects.
+#' A `.checkpoint.compress` argument can be set to overwrite the `compress` argument in `saveRDS`
+#' used to save the checkpointed data. The current default for `saveRDS` is `gunzip (gz)`, which
+#' provides fast compression that usually works well on `netsim` objects.
 #'
-#' By default, if \code{netsim} reaches the end of all simulations, the
-#' checkpoint data directory and its content are removed before returning the
-#' \code{netsim} object. The \code{.checkpoint.keep} argument can be set to TRUE
-#' to prevent this removal to inspect the raw simulation objects.
+#' By default, if `netsim` reaches the end of all simulations, the checkpoint data directory and its
+#' content are removed before returning the `netsim` object. The `.checkpoint.keep` argument can be
+#' set to `TRUE` to prevent this removal to inspect the raw simulation objects.
 #'
 #' @section New Modules:
-#' Base network models use a set of module functions that specify how the
-#' individual nodes in the network are subjected to infection, recovery,
-#' demographics, and other processes. Core modules are those listed in the
-#' \code{.FUN} arguments. For each module, there is a default function used in
-#' the simulation. The default infection module, for example, is contained in
-#' the \code{\link{infection.net}} function.
+#' Base network models use a set of module functions that specify how the individual nodes in the
+#' network are subjected to infection, recovery, demographics, and other processes. Core modules are
+#' those listed in the `.FUN` arguments. For each module, there is a default function used in
+#' the simulation. The default infection module, for example, is contained in the [`infection.net`]
+#' function.
 #'
-#' For original models, one may substitute replacement module functions for any
-#' of the default functions. New modules may be added to the workflow at each
-#' time step by passing a module function via the \code{...} argument. Consult
-#' the \href{http://www.epimodel.org/tut.html}{New Network Models} tutorials.
-#' One may remove existing modules, such as \code{arrivals.FUN}, from the
-#' workflow by setting the parameter value for that argument to \code{NULL}.
+#' For original models, one may substitute replacement module functions for any of the default
+#' functions. New modules may be added to the workflow at each time step by passing a module function
+#' via the `...` argument. Consult the [New Network Models](http://www.epimodel.org/tut.html)
+#' tutorials. One may remove existing modules, such as `arrivals.FUN`, from the workflow by setting
+#' the parameter value for that argument to `NULL`.
 #'
-#' @return An \code{EpiModel} object of class \code{control.net}.
+#' @return
+#' An EpiModel object of class `control.net`.
 #'
-#' @seealso Use \code{\link{param.net}} to specify model parameters and
-#'          \code{\link{init.net}} to specify the initial conditions. Run the
-#'          parameterized model with \code{\link{netsim}}.
+#' @seealso
+#' Use [`param.net`] to specify model parameters and [`init.net`] to specify the initial conditions.
+#' Run the parameterized model with [`netsim`].
 #'
 #' @keywords parameterization
 #'
@@ -912,12 +843,12 @@ control.net <- function(type,
                         skip.check = FALSE,
                         raw.output = FALSE,
                         tergmLite.track.duration = FALSE,
-                        set.control.ergm = control.simulate.formula(
-                          MCMC.burnin = 2e5),
+                        set.control.ergm = control.simulate.formula(MCMC.burnin = 2e5),
                         set.control.stergm = NULL,
                         set.control.tergm = control.simulate.formula.tergm(),
                         save.diss.stats = TRUE,
                         ...) {
+
   if (!missing(set.control.stergm)) {
     warning("set.control.stergm is deprecated and will be removed in a future
              version; use set.control.tergm instead.")
@@ -1029,8 +960,7 @@ control.net <- function(type,
     p[["save.network"]] <- FALSE
   }
   if (p[["tergmLite"]] == TRUE && p[["resimulate.network"]] == FALSE) {
-    message("Because tergmLite = TRUE, resetting resimulate.network = TRUE",
-            call. = FALSE)
+    message("Because tergmLite = TRUE, resetting resimulate.network = TRUE")
     p[["resimulate.network"]] <- TRUE
   }
 
