@@ -1,9 +1,9 @@
-#' Update list \code{x} using the elements of list \code{new.x}.
+#' @title Update List \code{x} Using the Elements of List \code{new.x}.
 #'
-#' @param x a list.
-#' @param new.x a list.
+#' @param x A list.
+#' @param new.x A list.
 #'
-#' @return The full \code{x} list with the modifications added by \code{new.x}
+#' @return The full \code{x} list with the modifications added by \code{new.x}.
 #'
 #' @details
 #' This function updates list \code{x} by name. If \code{x} and \code{new.x}
@@ -26,33 +26,30 @@ update_list <- function(x, new.x) {
   return(x)
 }
 
-#' Module to modify the controls or parameters during the simulation
+#' @title Function to Modify the Controls or Parameters During the Simulation
 #'
-#' @param dat Master list object containing a \code{networkDynamic} object and
-#'        other initialization information passed from \code{\link{netsim}}.
-#' @param at Current time step.
+#' @inheritParams recovery.net
 #'
-#' @return The updated \code{dat} Master list object.
+#' @inherit recovery.net return
 #'
 #' @details
-#' If a list \code{param.updater.list} is present in the parameters, this module
-#' will update the \code{param} list with new values at given timesteps.
-#' Similarily, if a list \code{control.updater.list} is present in the controls,
-#' this module will update the \code{param} list with new values at given
-#' timesteps.
-#' An updater is a list containing an \code{at} element governing when the
-#' changes will happen, an optional \code{verbose} Boolean controlling whether
-#' to output a message when a change is made (default = TRUE) and a \code{param}
-#' or \code{control} named list with the names being the same as the parameter /
-#' control names and the new value to update with. If the new value is a
-#' function but the old one is not, the function will be applied to the current
-#' element (see example).
+#' If a list \code{.param.updater.list} is present in the parameters, this
+#' function will update the \code{param} list with new values at given time
+#' steps. Similarly, if a list \code{.control.updater.list} is present in the
+#' controls, this function will update the \code{param} list with new values at
+#' given time steps. An updater is a list containing an \code{at} element
+#' governing when the changes will happen, an optional \code{verbose} Boolean
+#' controlling whether to output a message when a change is made (default =
+#' TRUE), and a \code{param} or \code{control} named list containing the new
+#' values(s) with which to update, with the names being the same as the
+#' parameter / control names. If the new value is a function but the old one is
+#' not, the function will be applied to the current element (see example).
 #'
 #' @examples
 #' \dontrun{
 #'
-#' # Create the param.updater.list
-#' param.updater.list <- list(
+#' # Create the .param.updater.list
+#' .param.updater.list <- list(
 #'   # this is one updater
 #'   list(
 #'     at = 10,
@@ -78,10 +75,10 @@ update_list <- function(x, new.x) {
 #'    act.rate = 0.5,
 #'    hiv.test.rate = rep(0.256, 3),
 #'    trans.scale = c(1, 2, 3),
-#'    param.updater.list = param.updater.list
+#'    .param.updater.list = param.updater.list
 #'  )
 #'
-#' # Create the control.updater.list
+#' # Create the .control.updater.list
 #' # these updaters will toggle on and off the verbosity of the model
 #' control.updater.list <- list(
 #'   list(
@@ -101,15 +98,12 @@ update_list <- function(x, new.x) {
 #'   )
 #' )
 #'
-#' # Enable the module in control, and add `control.updater.list` to it
+#' Add the control updaters to the `control` object
 #'  control <- control.net(
-#'    type = NULL, # must be NULL as we use a custom module
 #'    nsims = 1,
 #'    nsteps = 20,
 #'    verbose = FALSE,
-#'    updater.FUN = updater.net,
-#'    infection.FUN = infection.net,
-#'    control.updater.list = control.updater.list
+#'    .control.updater.list = control.updater.list
 #'  )
 #'
 #' nw <- network_initialize(n = 50)
@@ -127,8 +121,9 @@ update_list <- function(x, new.x) {
 #'
 #' }
 #'
-#' @export
-updater.net <- function(dat, at) {
+#' @keywords internal
+#' @noRd
+input_updater <- function(dat) {
   for (type in c("param", "control")) {
     dat <- common_updater(dat, type)
   }
@@ -136,13 +131,12 @@ updater.net <- function(dat, at) {
   return(dat)
 }
 
-#' Update either the "param" or "control" list
+#' @title Update Either the "param" or "control" List
 #'
-#' @param dat Master list object containing a \code{networkDynamic} object and
-#'        other initialization information passed from \code{\link{netsim}}.
-#' @param type either "param" or "control"
+#' @inheritParams recovery.net
+#' @param type Either \code{"param"} or \code{"control"}.
 #'
-#' @return The updated \code{dat} Master list object.
+#' @inherit recovery.net return
 #'
 #' @keywords internal
 common_updater <- function(dat, type) {
@@ -151,13 +145,13 @@ common_updater <- function(dat, type) {
     type.label <- "parameters"
     type.set <- set_param
     type.get_list <- get_param_list
-    updaters.label <- "param.updater.list"
+    updaters.label <- ".param.updater.list"
     updaters <- get_param(dat, updaters.label, override.null.error = TRUE)
   } else if (type == "control") {
     type.label <- "controls"
     type.set <- set_control
     type.get_list <- get_control_list
-    updaters.label <- "control.updater.list"
+    updaters.label <- ".control.updater.list"
     updaters <- get_control(dat, updaters.label, override.null.error = TRUE)
   } else {
     stop("`type` must be either 'param' or 'control'")
@@ -181,7 +175,7 @@ common_updater <- function(dat, type) {
       if (verbose) {
         message(
           "\n\nAt timestep = ", at, " the following ", type.label,
-          " where modified:",
+          " were modified:",
           "\n'", paste0(names(new.list), collapse = "', '"), "'"
         )
       }
